print("import: 'psutil'")
import psutil

print("import: 'psutil._psutil_posix'")
import psutil._psutil_posix

print("import: 'psutil._psutil_osx'")
import psutil._psutil_osx

print("import: 'psutil.tests'")
import psutil.tests

